Welcome to sagbescheid's documentation!
=======================================

Contents:

.. toctree::
   :maxdepth: 2

   setup
   usage

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
